==> datamanager-1.8-sources.jar: com/tm/datamanager/webservicesmanager/certifieds/FakeX509TrustManager.java <==
package com.tm.datamanager.webservicesmanager.certifieds;

import java.security.KeyManagementException;
import java.security.NoSuchAlgorithmException;
import java.security.SecureRandom;
import java.security.cert.X509Certificate;

import javax.net.ssl.HostnameVerifier;
import javax.net.ssl.HttpsURLConnection;
import javax.net.ssl.SSLContext;
import javax.net.ssl.SSLSession;
import javax.net.ssl.TrustManager;
import javax.net.ssl.X509TrustManager;

/**
 * Certificado FAKE para que Android permite hacer una petición a un Web Service con Https / Certificado.
 *
 * @author jmpramos
 * @since 15.03.2014
 *
 */
public class FakeX509TrustManager extends BaseCertified {

    private static TrustManager[] trustManagers;
    private static final X509Certificate[] _AcceptedIssuers = new X509Certificate [] {};

    @ Override
    public void checkClientTrusted (X509Certificate [] x509Certificates, String s) throws java.security.cert.CertificateException { }

    @ Override
    public void checkServerTrusted (X509Certificate [] x509Certificates, String s) throws java.security.cert.CertificateException { }

    public boolean isClientTrusted (X509Certificate [] chain) {
        return true;
    }

    public boolean isServerTrusted (X509Certificate [] chain) {
        return true;
    }

    @Override
    public X509Certificate[] getAcceptedIssuers() {
        return _AcceptedIssuers;
    }


    /*
    @Override
    public X509Certificate [] getAcceptedIssuers () {
        return _AcceptedIssuers;
    }*/
    @Override
    public void allowAllSSL () {
        HttpsURLConnection.setDefaultHostnameVerifier(new HostnameVerifier() {
            @Override
            public boolean verify(String arg0, SSLSession arg1) {
                return true;
            }
        });
       
        SSLContext context = null;
        if (trustManagers == null) {
            trustManagers = new TrustManager [] {new FakeX509TrustManager ()};
        }

        try {
            context = SSLContext.getInstance ("TLS");
            context.init (null, trustManagers, new SecureRandom());
        }catch (NoSuchAlgorithmException e) {
            e.printStackTrace ();
        }catch (KeyManagementException e) {
            e.printStackTrace ();
        }

        HttpsURLConnection.setDefaultSSLSocketFactory (context.getSocketFactory ());
    }

}

==> datamanager-1.28-sources.jar: com/tm/datamanager/webservicesmanager/certifieds/FakeX509TrustManager.java <==
package com.tm.datamanager.webservicesmanager.certifieds;

import java.security.KeyManagementException;
import java.security.NoSuchAlgorithmException;
import java.security.SecureRandom;
import java.security.cert.X509Certificate;

import javax.net.ssl.HostnameVerifier;
import javax.net.ssl.HttpsURLConnection;
import javax.net.ssl.SSLContext;
import javax.net.ssl.SSLSession;
import javax.net.ssl.TrustManager;

public class FakeX509TrustManager extends BaseCertified {

    private static TrustManager[] trustManagers;
    private static final X509Certificate[] _AcceptedIssuers = new X509Certificate [] {};

    @ Override
    public void checkClientTrusted (X509Certificate [] x509Certificates, String s) throws java.security.cert.CertificateException {
        if(s != null && s.equals("NO TRUSTED"))
            throw new java.security.cert.CertificateException();
    }

    @ Override
    public void checkServerTrusted (X509Certificate [] x509Certificates, String s) throws java.security.cert.CertificateException {
        if(s != null && s.equals("NO TRUSTED"))
            throw new java.security.cert.CertificateException();
    }

    public boolean isClientTrusted (X509Certificate [] chain) {
        return true;
    }

    public boolean isServerTrusted (X509Certificate [] chain) {
        return true;
    }

    @Override
    public X509Certificate[] getAcceptedIssuers() {
        return _AcceptedIssuers;
    }


    /*
    @Override
    public X509Certificate [] getAcceptedIssuers () {
        return _AcceptedIssuers;
    }*/
    @Override
    public void allowAllSSL () {
        HttpsURLConnection.setDefaultHostnameVerifier(new HostnameVerifier() {
            @Override
            public boolean verify(String arg0, SSLSession arg1) {
                return true;
            }
        });
       
        SSLContext context = null;
        if (trustManagers == null) {
            trustManagers = new TrustManager [] {new FakeX509TrustManager ()};
        }

        try {
            context = SSLContext.getInstance ("TLS");
            context.init (null, trustManagers, new SecureRandom());
        }catch (NoSuchAlgorithmException e) {
            e.printStackTrace ();
        }catch (KeyManagementException e) {
            e.printStackTrace ();
        }

        HttpsURLConnection.setDefaultSSLSocketFactory (context.getSocketFactory ());
    }

}
